package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.BERSequence;
import cn.com.infosec.asn1.BERSet;
import cn.com.infosec.asn1.BERTaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERTaggedObject;
import java.util.Enumeration;

public class SignedData extends ASN1Encodable {
   private DERInteger version;
   private ASN1Set digestAlgorithms;
   private ContentInfo contentInfo;
   private ASN1Set certificates;
   private ASN1Set crls;
   private ASN1Set signerInfos;
   private boolean certsBer;
   private boolean crlsBer;

   public static SignedData getInstance(Object o) {
      if (o instanceof SignedData) {
         return (SignedData)o;
      } else if (o instanceof ASN1Sequence) {
         return new SignedData((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + o.getClass().getName());
      }
   }

   public SignedData(ASN1Set digestAlgorithms, ContentInfo contentInfo, ASN1Set certificates, ASN1Set crls, ASN1Set signerInfos) {
      this.version = this.calculateVersion(contentInfo.getContentType(), certificates, crls, signerInfos);
      this.digestAlgorithms = digestAlgorithms;
      this.contentInfo = contentInfo;
      this.certificates = certificates;
      this.crls = crls;
      this.signerInfos = signerInfos;
      this.crlsBer = crls instanceof BERSet;
      this.certsBer = certificates instanceof BERSet;
   }

   private DERInteger calculateVersion(DERObjectIdentifier contentOid, ASN1Set certs, ASN1Set crls, ASN1Set signerInfs) {
      boolean var5 = false;
      boolean var6 = false;
      boolean var7 = false;
      boolean var8 = false;
      Enumeration certs1;
      if (certs != null) {
         certs1 = certs.getObjects();

         while(certs1.hasMoreElements()) {
            Object var9;
            if ((var9 = certs1.nextElement()) instanceof ASN1TaggedObject) {
               ASN1TaggedObject var11;
               if ((var11 = (ASN1TaggedObject)var9).getTagNo() == 1) {
                  var7 = true;
               } else if (var11.getTagNo() == 2) {
                  var8 = true;
               } else if (var11.getTagNo() == 3) {
                  var5 = true;
               }
            }
         }
      }

      if (var5) {
         return new DERInteger(5);
      } else {
         if (crls != null) {
            certs1 = crls.getObjects();

            while(certs1.hasMoreElements()) {
               if (certs1.nextElement() instanceof ASN1TaggedObject) {
                  var6 = true;
               }
            }
         }

         if (var6) {
            return new DERInteger(5);
         } else if (var8) {
            return new DERInteger(4);
         } else if (var7) {
            return new DERInteger(3);
         } else if (contentOid.equals(CMSObjectIdentifiers.data)) {
            return this.checkForVersion3(signerInfs) ? new DERInteger(3) : new DERInteger(1);
         } else {
            return new DERInteger(3);
         }
      }
   }

   private boolean checkForVersion3(ASN1Set signerInfs) {
      Enumeration var2 = signerInfs.getObjects();

      while(var2.hasMoreElements()) {
         if (SignerInfo.getInstance(var2.nextElement()).getVersion().getValue().intValue() == 3) {
            return true;
         }
      }

      return false;
   }

   public SignedData(ASN1Sequence seq) {
      Enumeration seq1;
      this.version = (DERInteger)(seq1 = seq.getObjects()).nextElement();
      this.digestAlgorithms = (ASN1Set)seq1.nextElement();
      this.contentInfo = ContentInfo.getInstance(seq1.nextElement());

      while(seq1.hasMoreElements()) {
         DERObject var2;
         if ((var2 = (DERObject)seq1.nextElement()) instanceof ASN1TaggedObject) {
            int var3;
            ASN1TaggedObject var5;
            if ((var3 = (var5 = (ASN1TaggedObject)var2).getTagNo()) != 0) {
               if (var3 != 1) {
                  throw new IllegalArgumentException("unknown tag value " + var5.getTagNo());
               }

               this.crlsBer = var5 instanceof BERTaggedObject;
               this.crls = ASN1Set.getInstance(var5, false);
            } else {
               this.certsBer = var5 instanceof BERTaggedObject;
               this.certificates = ASN1Set.getInstance(var5, false);
            }
         } else {
            this.signerInfos = (ASN1Set)var2;
         }
      }

   }

   public DERInteger getVersion() {
      return this.version;
   }

   public ASN1Set getDigestAlgorithms() {
      return this.digestAlgorithms;
   }

   public ContentInfo getEncapContentInfo() {
      return this.contentInfo;
   }

   public ASN1Set getCertificates() {
      return this.certificates;
   }

   public ASN1Set getCRLs() {
      return this.crls;
   }

   public ASN1Set getSignerInfos() {
      return this.signerInfos;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var1.add(this.digestAlgorithms);
      var10001.add(this.contentInfo);
      ASN1Set var2;
      BERTaggedObject var3;
      DERTaggedObject var4;
      if ((var2 = this.certificates) != null) {
         if (this.certsBer) {
            var3 = new BERTaggedObject.<init>(false, 0, var2);
            var1.add(var3);
         } else {
            var4 = new DERTaggedObject.<init>(false, 0, var2);
            var1.add(var4);
         }
      }

      if ((var2 = this.crls) != null) {
         if (this.crlsBer) {
            var3 = new BERTaggedObject.<init>(false, 1, var2);
            var1.add(var3);
         } else {
            var4 = new DERTaggedObject.<init>(false, 1, var2);
            var1.add(var4);
         }
      }

      var1.add(this.signerInfos);
      return new BERSequence(var1);
   }
}
